# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class ProcessorResponseCode(object):

    """Implementation of the 'Processor Response Code' enum.

    Processor response code for the non-PayPal payment processor errors.

    Attributes:
        ENUM_0000: The enum member of type str.
        ENUM_00N7: The enum member of type str.
        ENUM_0100: The enum member of type str.
        ENUM_0390: The enum member of type str.
        ENUM_0500: The enum member of type str.
        ENUM_0580: The enum member of type str.
        ENUM_0800: The enum member of type str.
        ENUM_0880: The enum member of type str.
        ENUM_0890: The enum member of type str.
        ENUM_0960: The enum member of type str.
        ENUM_0R00: The enum member of type str.
        ENUM_1000: The enum member of type str.
        ENUM_10BR: The enum member of type str.
        ENUM_1300: The enum member of type str.
        ENUM_1310: The enum member of type str.
        ENUM_1312: The enum member of type str.
        ENUM_1317: The enum member of type str.
        ENUM_1320: The enum member of type str.
        ENUM_1330: The enum member of type str.
        ENUM_1335: The enum member of type str.
        ENUM_1340: The enum member of type str.
        ENUM_1350: The enum member of type str.
        ENUM_1352: The enum member of type str.
        ENUM_1360: The enum member of type str.
        ENUM_1370: The enum member of type str.
        ENUM_1380: The enum member of type str.
        ENUM_1382: The enum member of type str.
        ENUM_1384: The enum member of type str.
        ENUM_1390: The enum member of type str.
        ENUM_1393: The enum member of type str.
        ENUM_5100: The enum member of type str.
        ENUM_5110: The enum member of type str.
        ENUM_5120: The enum member of type str.
        ENUM_5130: The enum member of type str.
        ENUM_5135: The enum member of type str.
        ENUM_5140: The enum member of type str.
        ENUM_5150: The enum member of type str.
        ENUM_5160: The enum member of type str.
        ENUM_5170: The enum member of type str.
        ENUM_5180: The enum member of type str.
        ENUM_5190: The enum member of type str.
        ENUM_5200: The enum member of type str.
        ENUM_5210: The enum member of type str.
        ENUM_5400: The enum member of type str.
        ENUM_5500: The enum member of type str.
        ENUM_5650: The enum member of type str.
        ENUM_5700: The enum member of type str.
        ENUM_5710: The enum member of type str.
        ENUM_5800: The enum member of type str.
        ENUM_5900: The enum member of type str.
        ENUM_5910: The enum member of type str.
        ENUM_5920: The enum member of type str.
        ENUM_5930: The enum member of type str.
        ENUM_5950: The enum member of type str.
        ENUM_6300: The enum member of type str.
        ENUM_7600: The enum member of type str.
        ENUM_7700: The enum member of type str.
        ENUM_7710: The enum member of type str.
        ENUM_7800: The enum member of type str.
        ENUM_7900: The enum member of type str.
        ENUM_8000: The enum member of type str.
        ENUM_8010: The enum member of type str.
        ENUM_8020: The enum member of type str.
        ENUM_8030: The enum member of type str.
        ENUM_8100: The enum member of type str.
        ENUM_8110: The enum member of type str.
        ENUM_8220: The enum member of type str.
        ENUM_9100: The enum member of type str.
        ENUM_9500: The enum member of type str.
        ENUM_9510: The enum member of type str.
        ENUM_9520: The enum member of type str.
        ENUM_9530: The enum member of type str.
        ENUM_9540: The enum member of type str.
        ENUM_9600: The enum member of type str.
        PCNR: The enum member of type str.
        PCVV: The enum member of type str.
        PP06: The enum member of type str.
        PPRN: The enum member of type str.
        PPAD: The enum member of type str.
        PPAB: The enum member of type str.
        PPAE: The enum member of type str.
        PPAG: The enum member of type str.
        PPAI: The enum member of type str.
        PPAR: The enum member of type str.
        PPAU: The enum member of type str.
        PPAV: The enum member of type str.
        PPAX: The enum member of type str.
        PPBG: The enum member of type str.
        PPC2: The enum member of type str.
        PPCE: The enum member of type str.
        PPCO: The enum member of type str.
        PPCR: The enum member of type str.
        PPCT: The enum member of type str.
        PPCU: The enum member of type str.
        PPD3: The enum member of type str.
        PPDC: The enum member of type str.
        PPDI: The enum member of type str.
        PPDV: The enum member of type str.
        PPDT: The enum member of type str.
        PPEF: The enum member of type str.
        PPEL: The enum member of type str.
        PPER: The enum member of type str.
        PPEX: The enum member of type str.
        PPFE: The enum member of type str.
        PPFI: The enum member of type str.
        PPFR: The enum member of type str.
        PPFV: The enum member of type str.
        PPGR: The enum member of type str.
        PPH1: The enum member of type str.
        PPIF: The enum member of type str.
        PPII: The enum member of type str.
        PPIM: The enum member of type str.
        PPIT: The enum member of type str.
        PPLR: The enum member of type str.
        PPLS: The enum member of type str.
        PPMB: The enum member of type str.
        PPMC: The enum member of type str.
        PPMD: The enum member of type str.
        PPNC: The enum member of type str.
        PPNL: The enum member of type str.
        PPNM: The enum member of type str.
        PPNT: The enum member of type str.
        PPPH: The enum member of type str.
        PPPI: The enum member of type str.
        PPPM: The enum member of type str.
        PPQC: The enum member of type str.
        PPRE: The enum member of type str.
        PPRF: The enum member of type str.
        PPRR: The enum member of type str.
        PPS0: The enum member of type str.
        PPS1: The enum member of type str.
        PPS2: The enum member of type str.
        PPS3: The enum member of type str.
        PPS4: The enum member of type str.
        PPS5: The enum member of type str.
        PPS6: The enum member of type str.
        PPSC: The enum member of type str.
        PPSD: The enum member of type str.
        PPSE: The enum member of type str.
        PPTE: The enum member of type str.
        PPTF: The enum member of type str.
        PPTI: The enum member of type str.
        PPTR: The enum member of type str.
        PPTT: The enum member of type str.
        PPTV: The enum member of type str.
        PPUA: The enum member of type str.
        PPUC: The enum member of type str.
        PPUE: The enum member of type str.
        PPUI: The enum member of type str.
        PPUP: The enum member of type str.
        PPUR: The enum member of type str.
        PPVC: The enum member of type str.
        PPVE: The enum member of type str.
        PPVT: The enum member of type str.

    """
    ENUM_0000 = '0000'

    ENUM_00N7 = '00N7'

    ENUM_0100 = '0100'

    ENUM_0390 = '0390'

    ENUM_0500 = '0500'

    ENUM_0580 = '0580'

    ENUM_0800 = '0800'

    ENUM_0880 = '0880'

    ENUM_0890 = '0890'

    ENUM_0960 = '0960'

    ENUM_0R00 = '0R00'

    ENUM_1000 = '1000'

    ENUM_10BR = '10BR'

    ENUM_1300 = '1300'

    ENUM_1310 = '1310'

    ENUM_1312 = '1312'

    ENUM_1317 = '1317'

    ENUM_1320 = '1320'

    ENUM_1330 = '1330'

    ENUM_1335 = '1335'

    ENUM_1340 = '1340'

    ENUM_1350 = '1350'

    ENUM_1352 = '1352'

    ENUM_1360 = '1360'

    ENUM_1370 = '1370'

    ENUM_1380 = '1380'

    ENUM_1382 = '1382'

    ENUM_1384 = '1384'

    ENUM_1390 = '1390'

    ENUM_1393 = '1393'

    ENUM_5100 = '5100'

    ENUM_5110 = '5110'

    ENUM_5120 = '5120'

    ENUM_5130 = '5130'

    ENUM_5135 = '5135'

    ENUM_5140 = '5140'

    ENUM_5150 = '5150'

    ENUM_5160 = '5160'

    ENUM_5170 = '5170'

    ENUM_5180 = '5180'

    ENUM_5190 = '5190'

    ENUM_5200 = '5200'

    ENUM_5210 = '5210'

    ENUM_5400 = '5400'

    ENUM_5500 = '5500'

    ENUM_5650 = '5650'

    ENUM_5700 = '5700'

    ENUM_5710 = '5710'

    ENUM_5800 = '5800'

    ENUM_5900 = '5900'

    ENUM_5910 = '5910'

    ENUM_5920 = '5920'

    ENUM_5930 = '5930'

    ENUM_5950 = '5950'

    ENUM_6300 = '6300'

    ENUM_7600 = '7600'

    ENUM_7700 = '7700'

    ENUM_7710 = '7710'

    ENUM_7800 = '7800'

    ENUM_7900 = '7900'

    ENUM_8000 = '8000'

    ENUM_8010 = '8010'

    ENUM_8020 = '8020'

    ENUM_8030 = '8030'

    ENUM_8100 = '8100'

    ENUM_8110 = '8110'

    ENUM_8220 = '8220'

    ENUM_9100 = '9100'

    ENUM_9500 = '9500'

    ENUM_9510 = '9510'

    ENUM_9520 = '9520'

    ENUM_9530 = '9530'

    ENUM_9540 = '9540'

    ENUM_9600 = '9600'

    PCNR = 'PCNR'

    PCVV = 'PCVV'

    PP06 = 'PP06'

    PPRN = 'PPRN'

    PPAD = 'PPAD'

    PPAB = 'PPAB'

    PPAE = 'PPAE'

    PPAG = 'PPAG'

    PPAI = 'PPAI'

    PPAR = 'PPAR'

    PPAU = 'PPAU'

    PPAV = 'PPAV'

    PPAX = 'PPAX'

    PPBG = 'PPBG'

    PPC2 = 'PPC2'

    PPCE = 'PPCE'

    PPCO = 'PPCO'

    PPCR = 'PPCR'

    PPCT = 'PPCT'

    PPCU = 'PPCU'

    PPD3 = 'PPD3'

    PPDC = 'PPDC'

    PPDI = 'PPDI'

    PPDV = 'PPDV'

    PPDT = 'PPDT'

    PPEF = 'PPEF'

    PPEL = 'PPEL'

    PPER = 'PPER'

    PPEX = 'PPEX'

    PPFE = 'PPFE'

    PPFI = 'PPFI'

    PPFR = 'PPFR'

    PPFV = 'PPFV'

    PPGR = 'PPGR'

    PPH1 = 'PPH1'

    PPIF = 'PPIF'

    PPII = 'PPII'

    PPIM = 'PPIM'

    PPIT = 'PPIT'

    PPLR = 'PPLR'

    PPLS = 'PPLS'

    PPMB = 'PPMB'

    PPMC = 'PPMC'

    PPMD = 'PPMD'

    PPNC = 'PPNC'

    PPNL = 'PPNL'

    PPNM = 'PPNM'

    PPNT = 'PPNT'

    PPPH = 'PPPH'

    PPPI = 'PPPI'

    PPPM = 'PPPM'

    PPQC = 'PPQC'

    PPRE = 'PPRE'

    PPRF = 'PPRF'

    PPRR = 'PPRR'

    PPS0 = 'PPS0'

    PPS1 = 'PPS1'

    PPS2 = 'PPS2'

    PPS3 = 'PPS3'

    PPS4 = 'PPS4'

    PPS5 = 'PPS5'

    PPS6 = 'PPS6'

    PPSC = 'PPSC'

    PPSD = 'PPSD'

    PPSE = 'PPSE'

    PPTE = 'PPTE'

    PPTF = 'PPTF'

    PPTI = 'PPTI'

    PPTR = 'PPTR'

    PPTT = 'PPTT'

    PPTV = 'PPTV'

    PPUA = 'PPUA'

    PPUC = 'PPUC'

    PPUE = 'PPUE'

    PPUI = 'PPUI'

    PPUP = 'PPUP'

    PPUR = 'PPUR'

    PPVC = 'PPVC'

    PPVE = 'PPVE'

    PPVT = 'PPVT'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.apple_pay_attributes_response import ApplePayAttributesResponse
from paypalrestapis.models.apple_pay_card_response import ApplePayCardResponse
from paypalrestapis.models.phone_number import PhoneNumber


class ApplePayPaymentObject(object):

    """Implementation of the 'Apple Pay Payment Object' model.

    Information needed to pay using ApplePay.

    Attributes:
        id (str): ApplePay transaction identifier, this will be the unique
            identifier for this transaction provided by Apple. The pattern is
            defined by an external party and supports Unicode.
        token (str): Encrypted ApplePay token, containing card information.
            This token would be base64encoded. The pattern is defined by an
            external party and supports Unicode.
        name (str): The full name representation like Mr J Smith.
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign exists.</blockquote>
        phone_number (PhoneNumber): The phone number in its canonical
            international [E.164 numbering plan
            format](https://www.itu.int/rec/T-REC-E.164/en).
        card (ApplePayCardResponse): The Card from Apple Pay Wallet used to
            fund the payment.
        attributes (ApplePayAttributesResponse): Additional attributes
            associated with the use of Apple Pay.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": 'id',
        "token": 'token',
        "name": 'name',
        "email_address": 'email_address',
        "phone_number": 'phone_number',
        "card": 'card',
        "attributes": 'attributes'
    }

    _optionals = [
        'id',
        'token',
        'name',
        'email_address',
        'phone_number',
        'card',
        'attributes',
    ]

    def __init__(self,
                 id=APIHelper.SKIP,
                 token=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 email_address=APIHelper.SKIP,
                 phone_number=APIHelper.SKIP,
                 card=APIHelper.SKIP,
                 attributes=APIHelper.SKIP):
        """Constructor for the ApplePayPaymentObject class"""

        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id 
        if token is not APIHelper.SKIP:
            self.token = token 
        if name is not APIHelper.SKIP:
            self.name = name 
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if phone_number is not APIHelper.SKIP:
            self.phone_number = phone_number 
        if card is not APIHelper.SKIP:
            self.card = card 
        if attributes is not APIHelper.SKIP:
            self.attributes = attributes 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        token = dictionary.get("token") if dictionary.get("token") else APIHelper.SKIP
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        phone_number = PhoneNumber.from_dictionary(dictionary.get('phone_number')) if 'phone_number' in dictionary.keys() else APIHelper.SKIP
        card = ApplePayCardResponse.from_dictionary(dictionary.get('card')) if 'card' in dictionary.keys() else APIHelper.SKIP
        attributes = ApplePayAttributesResponse.from_dictionary(dictionary.get('attributes')) if 'attributes' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(id,
                   token,
                   name,
                   email_address,
                   phone_number,
                   card,
                   attributes)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'token={(self.token if hasattr(self, "token") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!r}, '
                f'phone_number={(self.phone_number if hasattr(self, "phone_number") else None)!r}, '
                f'card={(self.card if hasattr(self, "card") else None)!r}, '
                f'attributes={(self.attributes if hasattr(self, "attributes") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'token={(self.token if hasattr(self, "token") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!s}, '
                f'phone_number={(self.phone_number if hasattr(self, "phone_number") else None)!s}, '
                f'card={(self.card if hasattr(self, "card") else None)!s}, '
                f'attributes={(self.attributes if hasattr(self, "attributes") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.apple_pay_card import ApplePayCard


class ApplePayPaymentToken(object):

    """Implementation of the 'Apple Pay Payment Token' model.

    A resource representing a response for Apple Pay.

    Attributes:
        card (ApplePayCard): The payment card to be used to fund a payment.
            Can be a credit or debit card.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "card": 'card'
    }

    _optionals = [
        'card',
    ]

    def __init__(self,
                 card=APIHelper.SKIP):
        """Constructor for the ApplePayPaymentToken class"""

        # Initialize members of the class
        if card is not APIHelper.SKIP:
            self.card = card 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        card = ApplePayCard.from_dictionary(dictionary.get('card')) if 'card' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(card)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'card={(self.card if hasattr(self, "card") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'card={(self.card if hasattr(self, "card") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class InstrumentAuthorizationStatus(object):

    """Implementation of the 'Instrument Authorization Status' enum.

    The authorization status of the wallet instrument.

    Attributes:
        AUTHORIZED: The enum member of type str.
        BLOCKED: The enum member of type str.
        FAILED: The enum member of type str.
        NOT_APPLICABLE: The enum member of type str.
        NOT_SUPPORTED: The enum member of type str.
        UNAUTHORIZED: The enum member of type str.

    """
    AUTHORIZED = 'AUTHORIZED'

    BLOCKED = 'BLOCKED'

    FAILED = 'FAILED'

    NOT_APPLICABLE = 'NOT_APPLICABLE'

    NOT_SUPPORTED = 'NOT_SUPPORTED'

    UNAUTHORIZED = 'UNAUTHORIZED'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.google_pay_card_response import GooglePayCardResponse
from paypalrestapis.models.phone_number_with_country_code import PhoneNumberWithCountryCode


class GooglePayWalletResponse(object):

    """Implementation of the 'Google Pay Wallet Response' model.

    Google Pay Wallet payment data.

    Attributes:
        name (str): The full name representation like Mr J Smith.
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign exists.</blockquote>
        phone_number (PhoneNumberWithCountryCode): The phone number in its
            canonical international [E.164 numbering plan
            format](https://www.itu.int/rec/T-REC-E.164/en).
        card (GooglePayCardResponse): The payment card to use to fund a Google
            Pay payment response. Can be a credit or debit card.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "email_address": 'email_address',
        "phone_number": 'phone_number',
        "card": 'card'
    }

    _optionals = [
        'name',
        'email_address',
        'phone_number',
        'card',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 email_address=APIHelper.SKIP,
                 phone_number=APIHelper.SKIP,
                 card=APIHelper.SKIP):
        """Constructor for the GooglePayWalletResponse class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if phone_number is not APIHelper.SKIP:
            self.phone_number = phone_number 
        if card is not APIHelper.SKIP:
            self.card = card 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        phone_number = PhoneNumberWithCountryCode.from_dictionary(dictionary.get('phone_number')) if 'phone_number' in dictionary.keys() else APIHelper.SKIP
        card = GooglePayCardResponse.from_dictionary(dictionary.get('card')) if 'card' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   email_address,
                   phone_number,
                   card)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!r}, '
                f'phone_number={(self.phone_number if hasattr(self, "phone_number") else None)!r}, '
                f'card={(self.card if hasattr(self, "card") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!s}, '
                f'phone_number={(self.phone_number if hasattr(self, "phone_number") else None)!s}, '
                f'card={(self.card if hasattr(self, "card") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalPaymentTokenUsagePattern(object):

    """Implementation of the 'PayPal Payment Token Usage Pattern' enum.

    Expected business/pricing model for the billing agreement.

    Attributes:
        IMMEDIATE: The enum member of type str.
        DEFERRED: The enum member of type str.
        RECURRING_PREPAID: The enum member of type str.
        RECURRING_POSTPAID: The enum member of type str.
        THRESHOLD_PREPAID: The enum member of type str.
        THRESHOLD_POSTPAID: The enum member of type str.

    """
    IMMEDIATE = 'IMMEDIATE'

    DEFERRED = 'DEFERRED'

    RECURRING_PREPAID = 'RECURRING_PREPAID'

    RECURRING_POSTPAID = 'RECURRING_POSTPAID'

    THRESHOLD_PREPAID = 'THRESHOLD_PREPAID'

    THRESHOLD_POSTPAID = 'THRESHOLD_POSTPAID'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.authorization_status_details import AuthorizationStatusDetails
from paypalrestapis.models.link_description import LinkDescription
from paypalrestapis.models.money import Money
from paypalrestapis.models.network_transaction_reference import NetworkTransactionReference
from paypalrestapis.models.seller_protection import SellerProtection


class Authorization(object):

    """Implementation of the 'Authorization' model.

    The authorized payment transaction.

    Attributes:
        status (AuthorizationStatus): The status for the authorized payment.
        status_details (AuthorizationStatusDetails): The details of the
            authorized payment status.
        id (str): The PayPal-generated ID for the authorized payment.
        amount (Money): The currency and amount for a financial transaction,
            such as a balance or payment due.
        invoice_id (str): The API caller-provided external invoice number for
            this order. Appears in both the payer's transaction history and
            the emails that the payer receives.
        custom_id (str): The API caller-provided external ID. Used to
            reconcile API caller-initiated transactions with PayPal
            transactions. Appears in transaction and settlement reports.
        network_transaction_reference (NetworkTransactionReference): Reference
            values used by the card network to identify a transaction.
        seller_protection (SellerProtection): The level of protection offered
            as defined by [PayPal Seller Protection for
            Merchants](https://www.paypal.com/us/webapps/mpp/security/seller-pr
            otection).
        expiration_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        links (List[LinkDescription]): An array of related [HATEOAS
            links](/docs/api/reference/api-responses/#hateoas-links).
        create_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>
        update_time (str): The date and time, in [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6). Seconds
            are required while fractional seconds are
            optional.<blockquote><strong>Note:</strong> The regular expression
            provides guidance but does not reject all invalid
            dates.</blockquote>

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "status": 'status',
        "status_details": 'status_details',
        "id": 'id',
        "amount": 'amount',
        "invoice_id": 'invoice_id',
        "custom_id": 'custom_id',
        "network_transaction_reference": 'network_transaction_reference',
        "seller_protection": 'seller_protection',
        "expiration_time": 'expiration_time',
        "links": 'links',
        "create_time": 'create_time',
        "update_time": 'update_time'
    }

    _optionals = [
        'status',
        'status_details',
        'id',
        'amount',
        'invoice_id',
        'custom_id',
        'network_transaction_reference',
        'seller_protection',
        'expiration_time',
        'links',
        'create_time',
        'update_time',
    ]

    def __init__(self,
                 status=APIHelper.SKIP,
                 status_details=APIHelper.SKIP,
                 id=APIHelper.SKIP,
                 amount=APIHelper.SKIP,
                 invoice_id=APIHelper.SKIP,
                 custom_id=APIHelper.SKIP,
                 network_transaction_reference=APIHelper.SKIP,
                 seller_protection=APIHelper.SKIP,
                 expiration_time=APIHelper.SKIP,
                 links=APIHelper.SKIP,
                 create_time=APIHelper.SKIP,
                 update_time=APIHelper.SKIP):
        """Constructor for the Authorization class"""

        # Initialize members of the class
        if status is not APIHelper.SKIP:
            self.status = status 
        if status_details is not APIHelper.SKIP:
            self.status_details = status_details 
        if id is not APIHelper.SKIP:
            self.id = id 
        if amount is not APIHelper.SKIP:
            self.amount = amount 
        if invoice_id is not APIHelper.SKIP:
            self.invoice_id = invoice_id 
        if custom_id is not APIHelper.SKIP:
            self.custom_id = custom_id 
        if network_transaction_reference is not APIHelper.SKIP:
            self.network_transaction_reference = network_transaction_reference 
        if seller_protection is not APIHelper.SKIP:
            self.seller_protection = seller_protection 
        if expiration_time is not APIHelper.SKIP:
            self.expiration_time = expiration_time 
        if links is not APIHelper.SKIP:
            self.links = links 
        if create_time is not APIHelper.SKIP:
            self.create_time = create_time 
        if update_time is not APIHelper.SKIP:
            self.update_time = update_time 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        status = dictionary.get("status") if dictionary.get("status") else APIHelper.SKIP
        status_details = AuthorizationStatusDetails.from_dictionary(dictionary.get('status_details')) if 'status_details' in dictionary.keys() else APIHelper.SKIP
        id = dictionary.get("id") if dictionary.get("id") else APIHelper.SKIP
        amount = Money.from_dictionary(dictionary.get('amount')) if 'amount' in dictionary.keys() else APIHelper.SKIP
        invoice_id = dictionary.get("invoice_id") if dictionary.get("invoice_id") else APIHelper.SKIP
        custom_id = dictionary.get("custom_id") if dictionary.get("custom_id") else APIHelper.SKIP
        network_transaction_reference = NetworkTransactionReference.from_dictionary(dictionary.get('network_transaction_reference')) if 'network_transaction_reference' in dictionary.keys() else APIHelper.SKIP
        seller_protection = SellerProtection.from_dictionary(dictionary.get('seller_protection')) if 'seller_protection' in dictionary.keys() else APIHelper.SKIP
        expiration_time = dictionary.get("expiration_time") if dictionary.get("expiration_time") else APIHelper.SKIP
        links = None
        if dictionary.get('links') is not None:
            links = [LinkDescription.from_dictionary(x) for x in dictionary.get('links')]
        else:
            links = APIHelper.SKIP
        create_time = dictionary.get("create_time") if dictionary.get("create_time") else APIHelper.SKIP
        update_time = dictionary.get("update_time") if dictionary.get("update_time") else APIHelper.SKIP
        # Return an object of this model
        return cls(status,
                   status_details,
                   id,
                   amount,
                   invoice_id,
                   custom_id,
                   network_transaction_reference,
                   seller_protection,
                   expiration_time,
                   links,
                   create_time,
                   update_time)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'status={(self.status if hasattr(self, "status") else None)!r}, '
                f'status_details={(self.status_details if hasattr(self, "status_details") else None)!r}, '
                f'id={(self.id if hasattr(self, "id") else None)!r}, '
                f'amount={(self.amount if hasattr(self, "amount") else None)!r}, '
                f'invoice_id={(self.invoice_id if hasattr(self, "invoice_id") else None)!r}, '
                f'custom_id={(self.custom_id if hasattr(self, "custom_id") else None)!r}, '
                f'network_transaction_reference={(self.network_transaction_reference if hasattr(self, "network_transaction_reference") else None)!r}, '
                f'seller_protection={(self.seller_protection if hasattr(self, "seller_protection") else None)!r}, '
                f'expiration_time={(self.expiration_time if hasattr(self, "expiration_time") else None)!r}, '
                f'links={(self.links if hasattr(self, "links") else None)!r}, '
                f'create_time={(self.create_time if hasattr(self, "create_time") else None)!r}, '
                f'update_time={(self.update_time if hasattr(self, "update_time") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'status={(self.status if hasattr(self, "status") else None)!s}, '
                f'status_details={(self.status_details if hasattr(self, "status_details") else None)!s}, '
                f'id={(self.id if hasattr(self, "id") else None)!s}, '
                f'amount={(self.amount if hasattr(self, "amount") else None)!s}, '
                f'invoice_id={(self.invoice_id if hasattr(self, "invoice_id") else None)!s}, '
                f'custom_id={(self.custom_id if hasattr(self, "custom_id") else None)!s}, '
                f'network_transaction_reference={(self.network_transaction_reference if hasattr(self, "network_transaction_reference") else None)!s}, '
                f'seller_protection={(self.seller_protection if hasattr(self, "seller_protection") else None)!s}, '
                f'expiration_time={(self.expiration_time if hasattr(self, "expiration_time") else None)!s}, '
                f'links={(self.links if hasattr(self, "links") else None)!s}, '
                f'create_time={(self.create_time if hasattr(self, "create_time") else None)!s}, '
                f'update_time={(self.update_time if hasattr(self, "update_time") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PaymentInitiator(object):

    """Implementation of the 'Payment Initiator' enum.

    The person or party who initiated or triggered the payment.

    Attributes:
        CUSTOMER: The enum member of type str.
        MERCHANT: The enum member of type str.

    """
    CUSTOMER = 'CUSTOMER'

    MERCHANT = 'MERCHANT'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalWalletVaultStatus(object):

    """Implementation of the 'PayPal Wallet Vault Status' enum.

    The vault status.

    Attributes:
        VAULTED: The enum member of type str.
        CREATED: The enum member of type str.
        APPROVED: The enum member of type str.

    """
    VAULTED = 'VAULTED'

    CREATED = 'CREATED'

    APPROVED = 'APPROVED'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.universal_product_code import UniversalProductCode


class OrderTrackerItem(object):

    """Implementation of the 'Order Tracker Item' model.

    The details of the items in the shipment.

    Attributes:
        name (str): The item name or title.
        quantity (str): The item quantity. Must be a whole number.
        sku (str): The stock keeping unit (SKU) for the item. This can contain
            unicode characters.
        url (str): The URL to the item being purchased. Visible to buyer and
            used in buyer experiences.
        image_url (str): The URL of the item's image. File type and size
            restrictions apply. An image that violates these restrictions will
            not be honored.
        upc (UniversalProductCode): The Universal Product Code of the item.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "quantity": 'quantity',
        "sku": 'sku',
        "url": 'url',
        "image_url": 'image_url',
        "upc": 'upc'
    }

    _optionals = [
        'name',
        'quantity',
        'sku',
        'url',
        'image_url',
        'upc',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 quantity=APIHelper.SKIP,
                 sku=APIHelper.SKIP,
                 url=APIHelper.SKIP,
                 image_url=APIHelper.SKIP,
                 upc=APIHelper.SKIP):
        """Constructor for the OrderTrackerItem class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if quantity is not APIHelper.SKIP:
            self.quantity = quantity 
        if sku is not APIHelper.SKIP:
            self.sku = sku 
        if url is not APIHelper.SKIP:
            self.url = url 
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url 
        if upc is not APIHelper.SKIP:
            self.upc = upc 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        quantity = dictionary.get("quantity") if dictionary.get("quantity") else APIHelper.SKIP
        sku = dictionary.get("sku") if dictionary.get("sku") else APIHelper.SKIP
        url = dictionary.get("url") if dictionary.get("url") else APIHelper.SKIP
        image_url = dictionary.get("image_url") if dictionary.get("image_url") else APIHelper.SKIP
        upc = UniversalProductCode.from_dictionary(dictionary.get('upc')) if 'upc' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   quantity,
                   sku,
                   url,
                   image_url,
                   upc)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'quantity={(self.quantity if hasattr(self, "quantity") else None)!r}, '
                f'sku={(self.sku if hasattr(self, "sku") else None)!r}, '
                f'url={(self.url if hasattr(self, "url") else None)!r}, '
                f'image_url={(self.image_url if hasattr(self, "image_url") else None)!r}, '
                f'upc={(self.upc if hasattr(self, "upc") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'quantity={(self.quantity if hasattr(self, "quantity") else None)!s}, '
                f'sku={(self.sku if hasattr(self, "sku") else None)!s}, '
                f'url={(self.url if hasattr(self, "url") else None)!s}, '
                f'image_url={(self.image_url if hasattr(self, "image_url") else None)!s}, '
                f'upc={(self.upc if hasattr(self, "upc") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PAResStatus(object):

    """Implementation of the 'PARes Status' enum.

    Transactions status result identifier. The outcome of the issuer's
    authentication.

    Attributes:
        Y: The enum member of type str.
        N: The enum member of type str.
        U: The enum member of type str.
        A: The enum member of type str.
        C: The enum member of type str.
        R: The enum member of type str.
        D: The enum member of type str.
        I: The enum member of type str.

    """
    Y = 'Y'

    N = 'N'

    U = 'U'

    A = 'A'

    C = 'C'

    R = 'R'

    D = 'D'

    I = 'I'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalPaymentTokenCustomerType(object):

    """Implementation of the 'PayPal Payment Token Customer Type' enum.

    The customer type associated with the PayPal payment token. This is to
    indicate whether the customer acting on the merchant / platform is either
    a business or a consumer.

    Attributes:
        CONSUMER: The enum member of type str.
        BUSINESS: The enum member of type str.

    """
    CONSUMER = 'CONSUMER'

    BUSINESS = 'BUSINESS'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.address import Address
from paypalrestapis.models.shipping_name import ShippingName
from paypalrestapis.models.shipping_option import ShippingOption


class ShippingDetails(object):

    """Implementation of the 'Shipping Details' model.

    The shipping details.

    Attributes:
        name (ShippingName): The name of the party.
        mtype (FullfillmentType): A classification for the method of purchase
            fulfillment (e.g shipping, in-store pickup, etc). Either `type` or
            `options` may be present, but not both.
        options (List[ShippingOption]): An array of shipping options that the
            payee or merchant offers to the payer to ship or pick up their
            items.
        address (Address): The portable international postal address. Maps to
            [AddressValidationMetadata](https://github.com/googlei18n/libaddres
            sinput/wiki/AddressValidationMetadata) and HTML 5.1 [Autofilling
            form controls: the autocomplete
            attribute](https://www.w3.org/TR/html51/sec-forms.html#autofilling-
            form-controls-the-autocomplete-attribute).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "mtype": 'type',
        "options": 'options',
        "address": 'address'
    }

    _optionals = [
        'name',
        'mtype',
        'options',
        'address',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 options=APIHelper.SKIP,
                 address=APIHelper.SKIP):
        """Constructor for the ShippingDetails class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if options is not APIHelper.SKIP:
            self.options = options 
        if address is not APIHelper.SKIP:
            self.address = address 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = ShippingName.from_dictionary(dictionary.get('name')) if 'name' in dictionary.keys() else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        options = None
        if dictionary.get('options') is not None:
            options = [ShippingOption.from_dictionary(x) for x in dictionary.get('options')]
        else:
            options = APIHelper.SKIP
        address = Address.from_dictionary(dictionary.get('address')) if 'address' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   mtype,
                   options,
                   address)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!r}, '
                f'options={(self.options if hasattr(self, "options") else None)!r}, '
                f'address={(self.address if hasattr(self, "address") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!s}, '
                f'options={(self.options if hasattr(self, "options") else None)!s}, '
                f'address={(self.address if hasattr(self, "address") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper


class PayeeBase(object):

    """Implementation of the 'Payee Base' model.

    The details for the merchant who receives the funds and fulfills the
    order. The merchant is also known as the payee.

    Attributes:
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign exists.</blockquote>
        merchant_id (str): The account identifier for a PayPal account.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "email_address": 'email_address',
        "merchant_id": 'merchant_id'
    }

    _optionals = [
        'email_address',
        'merchant_id',
    ]

    def __init__(self,
                 email_address=APIHelper.SKIP,
                 merchant_id=APIHelper.SKIP):
        """Constructor for the PayeeBase class"""

        # Initialize members of the class
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if merchant_id is not APIHelper.SKIP:
            self.merchant_id = merchant_id 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        merchant_id = dictionary.get("merchant_id") if dictionary.get("merchant_id") else APIHelper.SKIP
        # Return an object of this model
        return cls(email_address,
                   merchant_id)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!r}, '
                f'merchant_id={(self.merchant_id if hasattr(self, "merchant_id") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!s}, '
                f'merchant_id={(self.merchant_id if hasattr(self, "merchant_id") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.address import Address
from paypalrestapis.models.name import Name
from paypalrestapis.models.phone_with_type import PhoneWithType
from paypalrestapis.models.vaulted_digital_wallet_shipping_details import VaultedDigitalWalletShippingDetails


class VenmoPaymentToken(object):

    """Implementation of the 'Venmo Payment Token' model.

    Attributes:
        description (str): The description displayed to the consumer on the
            approval flow for a digital wallet, as well as on the merchant
            view of the payment token management experience. exp: PayPal.com.
        shipping (VaultedDigitalWalletShippingDetails): The shipping details.
        permit_multiple_payment_tokens (bool): Create multiple payment tokens
            for the same payer, merchant/platform combination. Use this when
            the customer has not logged in at merchant/platform. The payment
            token thus generated, can then also be used to create the customer
            account at merchant/platform. Use this also when multiple payment
            tokens are required for the same payer, different customer at
            merchant/platform. This helps to identify customers distinctly
            even though they may share the same PayPal account. This only
            applies to PayPal payment source.
        usage_type (str): The usage type associated with a digital wallet
            payment token.
        customer_type (str): The customer type associated with a digital
            wallet payment token. This is to indicate whether the customer
            acting on the merchant / platform is either a business or a
            consumer.
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign exists.</blockquote>
        payer_id (str): The account identifier for a PayPal account.
        name (Name): The name of the party.
        phone (PhoneWithType): The phone information.
        address (Address): The portable international postal address. Maps to
            [AddressValidationMetadata](https://github.com/googlei18n/libaddres
            sinput/wiki/AddressValidationMetadata) and HTML 5.1 [Autofilling
            form controls: the autocomplete
            attribute](https://www.w3.org/TR/html51/sec-forms.html#autofilling-
            form-controls-the-autocomplete-attribute).
        user_name (str): The Venmo username, as chosen by the user.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "description": 'description',
        "shipping": 'shipping',
        "permit_multiple_payment_tokens": 'permit_multiple_payment_tokens',
        "usage_type": 'usage_type',
        "customer_type": 'customer_type',
        "email_address": 'email_address',
        "payer_id": 'payer_id',
        "name": 'name',
        "phone": 'phone',
        "address": 'address',
        "user_name": 'user_name'
    }

    _optionals = [
        'description',
        'shipping',
        'permit_multiple_payment_tokens',
        'usage_type',
        'customer_type',
        'email_address',
        'payer_id',
        'name',
        'phone',
        'address',
        'user_name',
    ]

    def __init__(self,
                 description=APIHelper.SKIP,
                 shipping=APIHelper.SKIP,
                 permit_multiple_payment_tokens=False,
                 usage_type=APIHelper.SKIP,
                 customer_type=APIHelper.SKIP,
                 email_address=APIHelper.SKIP,
                 payer_id=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 phone=APIHelper.SKIP,
                 address=APIHelper.SKIP,
                 user_name=APIHelper.SKIP):
        """Constructor for the VenmoPaymentToken class"""

        # Initialize members of the class
        if description is not APIHelper.SKIP:
            self.description = description 
        if shipping is not APIHelper.SKIP:
            self.shipping = shipping 
        self.permit_multiple_payment_tokens = permit_multiple_payment_tokens 
        if usage_type is not APIHelper.SKIP:
            self.usage_type = usage_type 
        if customer_type is not APIHelper.SKIP:
            self.customer_type = customer_type 
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if payer_id is not APIHelper.SKIP:
            self.payer_id = payer_id 
        if name is not APIHelper.SKIP:
            self.name = name 
        if phone is not APIHelper.SKIP:
            self.phone = phone 
        if address is not APIHelper.SKIP:
            self.address = address 
        if user_name is not APIHelper.SKIP:
            self.user_name = user_name 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        description = dictionary.get("description") if dictionary.get("description") else APIHelper.SKIP
        shipping = VaultedDigitalWalletShippingDetails.from_dictionary(dictionary.get('shipping')) if 'shipping' in dictionary.keys() else APIHelper.SKIP
        permit_multiple_payment_tokens = dictionary.get("permit_multiple_payment_tokens") if dictionary.get("permit_multiple_payment_tokens") else False
        usage_type = dictionary.get("usage_type") if dictionary.get("usage_type") else APIHelper.SKIP
        customer_type = dictionary.get("customer_type") if dictionary.get("customer_type") else APIHelper.SKIP
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        payer_id = dictionary.get("payer_id") if dictionary.get("payer_id") else APIHelper.SKIP
        name = Name.from_dictionary(dictionary.get('name')) if 'name' in dictionary.keys() else APIHelper.SKIP
        phone = PhoneWithType.from_dictionary(dictionary.get('phone')) if 'phone' in dictionary.keys() else APIHelper.SKIP
        address = Address.from_dictionary(dictionary.get('address')) if 'address' in dictionary.keys() else APIHelper.SKIP
        user_name = dictionary.get("user_name") if dictionary.get("user_name") else APIHelper.SKIP
        # Return an object of this model
        return cls(description,
                   shipping,
                   permit_multiple_payment_tokens,
                   usage_type,
                   customer_type,
                   email_address,
                   payer_id,
                   name,
                   phone,
                   address,
                   user_name)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'description={(self.description if hasattr(self, "description") else None)!r}, '
                f'shipping={(self.shipping if hasattr(self, "shipping") else None)!r}, '
                f'permit_multiple_payment_tokens={(self.permit_multiple_payment_tokens if hasattr(self, "permit_multiple_payment_tokens") else None)!r}, '
                f'usage_type={(self.usage_type if hasattr(self, "usage_type") else None)!r}, '
                f'customer_type={(self.customer_type if hasattr(self, "customer_type") else None)!r}, '
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!r}, '
                f'payer_id={(self.payer_id if hasattr(self, "payer_id") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'phone={(self.phone if hasattr(self, "phone") else None)!r}, '
                f'address={(self.address if hasattr(self, "address") else None)!r}, '
                f'user_name={(self.user_name if hasattr(self, "user_name") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'description={(self.description if hasattr(self, "description") else None)!s}, '
                f'shipping={(self.shipping if hasattr(self, "shipping") else None)!s}, '
                f'permit_multiple_payment_tokens={(self.permit_multiple_payment_tokens if hasattr(self, "permit_multiple_payment_tokens") else None)!s}, '
                f'usage_type={(self.usage_type if hasattr(self, "usage_type") else None)!s}, '
                f'customer_type={(self.customer_type if hasattr(self, "customer_type") else None)!s}, '
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!s}, '
                f'payer_id={(self.payer_id if hasattr(self, "payer_id") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'phone={(self.phone if hasattr(self, "phone") else None)!s}, '
                f'address={(self.address if hasattr(self, "address") else None)!s}, '
                f'user_name={(self.user_name if hasattr(self, "user_name") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.address import Address
from paypalrestapis.models.name import Name
from paypalrestapis.models.phone_number import PhoneNumber
from paypalrestapis.models.venmo_wallet_attributes_response import VenmoWalletAttributesResponse


class VenmoWalletResponse(object):

    """Implementation of the 'Venmo Wallet Response' model.

    Venmo wallet response.

    Attributes:
        email_address (str): The internationalized email
            address.<blockquote><strong>Note:</strong> Up to 64 characters are
            allowed before and 255 characters are allowed after the
            <code>@</code> sign. However, the generally accepted maximum
            length for an email address is 254 characters. The pattern
            verifies that an unquoted <code>@</code> sign exists.</blockquote>
        account_id (str): The PayPal payer ID, which is a masked version of
            the PayPal account number intended for use with third parties. The
            account number is reversibly encrypted and a proprietary variant
            of Base32 is used to encode the result.
        user_name (str): The Venmo user name chosen by the user, also know as
            a Venmo handle.
        name (Name): The name of the party.
        phone_number (PhoneNumber): The phone number in its canonical
            international [E.164 numbering plan
            format](https://www.itu.int/rec/T-REC-E.164/en).
        address (Address): The portable international postal address. Maps to
            [AddressValidationMetadata](https://github.com/googlei18n/libaddres
            sinput/wiki/AddressValidationMetadata) and HTML 5.1 [Autofilling
            form controls: the autocomplete
            attribute](https://www.w3.org/TR/html51/sec-forms.html#autofilling-
            form-controls-the-autocomplete-attribute).
        attributes (VenmoWalletAttributesResponse): Additional attributes
            associated with the use of a Venmo Wallet.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "email_address": 'email_address',
        "account_id": 'account_id',
        "user_name": 'user_name',
        "name": 'name',
        "phone_number": 'phone_number',
        "address": 'address',
        "attributes": 'attributes'
    }

    _optionals = [
        'email_address',
        'account_id',
        'user_name',
        'name',
        'phone_number',
        'address',
        'attributes',
    ]

    def __init__(self,
                 email_address=APIHelper.SKIP,
                 account_id=APIHelper.SKIP,
                 user_name=APIHelper.SKIP,
                 name=APIHelper.SKIP,
                 phone_number=APIHelper.SKIP,
                 address=APIHelper.SKIP,
                 attributes=APIHelper.SKIP):
        """Constructor for the VenmoWalletResponse class"""

        # Initialize members of the class
        if email_address is not APIHelper.SKIP:
            self.email_address = email_address 
        if account_id is not APIHelper.SKIP:
            self.account_id = account_id 
        if user_name is not APIHelper.SKIP:
            self.user_name = user_name 
        if name is not APIHelper.SKIP:
            self.name = name 
        if phone_number is not APIHelper.SKIP:
            self.phone_number = phone_number 
        if address is not APIHelper.SKIP:
            self.address = address 
        if attributes is not APIHelper.SKIP:
            self.attributes = attributes 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        email_address = dictionary.get("email_address") if dictionary.get("email_address") else APIHelper.SKIP
        account_id = dictionary.get("account_id") if dictionary.get("account_id") else APIHelper.SKIP
        user_name = dictionary.get("user_name") if dictionary.get("user_name") else APIHelper.SKIP
        name = Name.from_dictionary(dictionary.get('name')) if 'name' in dictionary.keys() else APIHelper.SKIP
        phone_number = PhoneNumber.from_dictionary(dictionary.get('phone_number')) if 'phone_number' in dictionary.keys() else APIHelper.SKIP
        address = Address.from_dictionary(dictionary.get('address')) if 'address' in dictionary.keys() else APIHelper.SKIP
        attributes = VenmoWalletAttributesResponse.from_dictionary(dictionary.get('attributes')) if 'attributes' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(email_address,
                   account_id,
                   user_name,
                   name,
                   phone_number,
                   address,
                   attributes)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!r}, '
                f'account_id={(self.account_id if hasattr(self, "account_id") else None)!r}, '
                f'user_name={(self.user_name if hasattr(self, "user_name") else None)!r}, '
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'phone_number={(self.phone_number if hasattr(self, "phone_number") else None)!r}, '
                f'address={(self.address if hasattr(self, "address") else None)!r}, '
                f'attributes={(self.attributes if hasattr(self, "attributes") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'email_address={(self.email_address if hasattr(self, "email_address") else None)!s}, '
                f'account_id={(self.account_id if hasattr(self, "account_id") else None)!s}, '
                f'user_name={(self.user_name if hasattr(self, "user_name") else None)!s}, '
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'phone_number={(self.phone_number if hasattr(self, "phone_number") else None)!s}, '
                f'address={(self.address if hasattr(self, "address") else None)!s}, '
                f'attributes={(self.attributes if hasattr(self, "attributes") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.ach_debit_response import ACHDebitResponse
from paypalrestapis.models.sepa_debit_response import SEPADebitResponse


class BankPaymentToken(object):

    """Implementation of the 'Bank Payment Token' model.

    Full representation of a Bank Payment Token.

    Attributes:
        ach_debit (ACHDebitResponse): A Resource representing a response of
            vaulted a ACH Debit Account.
        sepa_debit (SEPADebitResponse): The model property of type
            SEPADebitResponse.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "ach_debit": 'ach_debit',
        "sepa_debit": 'sepa_debit'
    }

    _optionals = [
        'ach_debit',
        'sepa_debit',
    ]

    def __init__(self,
                 ach_debit=APIHelper.SKIP,
                 sepa_debit=APIHelper.SKIP):
        """Constructor for the BankPaymentToken class"""

        # Initialize members of the class
        if ach_debit is not APIHelper.SKIP:
            self.ach_debit = ach_debit 
        if sepa_debit is not APIHelper.SKIP:
            self.sepa_debit = sepa_debit 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        ach_debit = ACHDebitResponse.from_dictionary(dictionary.get('ach_debit')) if 'ach_debit' in dictionary.keys() else APIHelper.SKIP
        sepa_debit = SEPADebitResponse.from_dictionary(dictionary.get('sepa_debit')) if 'sepa_debit' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(ach_debit,
                   sepa_debit)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'ach_debit={(self.ach_debit if hasattr(self, "ach_debit") else None)!r}, '
                f'sepa_debit={(self.sepa_debit if hasattr(self, "sepa_debit") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'ach_debit={(self.ach_debit if hasattr(self, "ach_debit") else None)!s}, '
                f'sepa_debit={(self.sepa_debit if hasattr(self, "sepa_debit") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.address_details import AddressDetails
from paypalrestapis.models.authentication_response import AuthenticationResponse
from paypalrestapis.models.bin_details import BinDetails
from paypalrestapis.models.card_verification_details import CardVerificationDetails
from paypalrestapis.models.network_transaction_reference_entity import NetworkTransactionReferenceEntity


class CardPaymentToken(object):

    """Implementation of the 'Card Payment Token' model.

    Full representation of a Card Payment Token including network token.

    Attributes:
        name (str): The card holder's name as it appears on the card.
        last_digits (str): The last digits of the payment card.
        brand (CardBrand): The card network or brand. Applies to credit,
            debit, gift, and payment cards.
        expiry (str): The year and month, in ISO-8601 `YYYY-MM` date format.
            See [Internet date and time
            format](https://tools.ietf.org/html/rfc3339#section-5.6).
        billing_address (AddressDetails): Address request details.
        verification_status (str): Verification status of Card.
        verification (CardVerificationDetails): Card Verification details
            including the authorization details and 3D SECURE details.
        network_transaction_reference (NetworkTransactionReferenceEntity):
            Previous network transaction reference including id in response.
        authentication_result (AuthenticationResponse): Results of
            Authentication such as 3D Secure.
        bin_details (BinDetails): Bank Identification Number (BIN) details
            used to fund a payment.
        mtype (CardType): Type of card. i.e Credit, Debit and so on.
        network_token (Any): The model property of type Any.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "last_digits": 'last_digits',
        "brand": 'brand',
        "expiry": 'expiry',
        "billing_address": 'billing_address',
        "verification_status": 'verification_status',
        "verification": 'verification',
        "network_transaction_reference": 'network_transaction_reference',
        "authentication_result": 'authentication_result',
        "bin_details": 'bin_details',
        "mtype": 'type',
        "network_token": 'network_token'
    }

    _optionals = [
        'name',
        'last_digits',
        'brand',
        'expiry',
        'billing_address',
        'verification_status',
        'verification',
        'network_transaction_reference',
        'authentication_result',
        'bin_details',
        'mtype',
        'network_token',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 last_digits=APIHelper.SKIP,
                 brand=APIHelper.SKIP,
                 expiry=APIHelper.SKIP,
                 billing_address=APIHelper.SKIP,
                 verification_status=APIHelper.SKIP,
                 verification=APIHelper.SKIP,
                 network_transaction_reference=APIHelper.SKIP,
                 authentication_result=APIHelper.SKIP,
                 bin_details=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 network_token=APIHelper.SKIP):
        """Constructor for the CardPaymentToken class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if last_digits is not APIHelper.SKIP:
            self.last_digits = last_digits 
        if brand is not APIHelper.SKIP:
            self.brand = brand 
        if expiry is not APIHelper.SKIP:
            self.expiry = expiry 
        if billing_address is not APIHelper.SKIP:
            self.billing_address = billing_address 
        if verification_status is not APIHelper.SKIP:
            self.verification_status = verification_status 
        if verification is not APIHelper.SKIP:
            self.verification = verification 
        if network_transaction_reference is not APIHelper.SKIP:
            self.network_transaction_reference = network_transaction_reference 
        if authentication_result is not APIHelper.SKIP:
            self.authentication_result = authentication_result 
        if bin_details is not APIHelper.SKIP:
            self.bin_details = bin_details 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if network_token is not APIHelper.SKIP:
            self.network_token = network_token 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        last_digits = dictionary.get("last_digits") if dictionary.get("last_digits") else APIHelper.SKIP
        brand = dictionary.get("brand") if dictionary.get("brand") else APIHelper.SKIP
        expiry = dictionary.get("expiry") if dictionary.get("expiry") else APIHelper.SKIP
        billing_address = AddressDetails.from_dictionary(dictionary.get('billing_address')) if 'billing_address' in dictionary.keys() else APIHelper.SKIP
        verification_status = dictionary.get("verification_status") if dictionary.get("verification_status") else APIHelper.SKIP
        verification = CardVerificationDetails.from_dictionary(dictionary.get('verification')) if 'verification' in dictionary.keys() else APIHelper.SKIP
        network_transaction_reference = NetworkTransactionReferenceEntity.from_dictionary(dictionary.get('network_transaction_reference')) if 'network_transaction_reference' in dictionary.keys() else APIHelper.SKIP
        authentication_result = AuthenticationResponse.from_dictionary(dictionary.get('authentication_result')) if 'authentication_result' in dictionary.keys() else APIHelper.SKIP
        bin_details = BinDetails.from_dictionary(dictionary.get('bin_details')) if 'bin_details' in dictionary.keys() else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        network_token = dictionary.get("network_token") if dictionary.get("network_token") else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   last_digits,
                   brand,
                   expiry,
                   billing_address,
                   verification_status,
                   verification,
                   network_transaction_reference,
                   authentication_result,
                   bin_details,
                   mtype,
                   network_token)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'last_digits={(self.last_digits if hasattr(self, "last_digits") else None)!r}, '
                f'brand={(self.brand if hasattr(self, "brand") else None)!r}, '
                f'expiry={(self.expiry if hasattr(self, "expiry") else None)!r}, '
                f'billing_address={(self.billing_address if hasattr(self, "billing_address") else None)!r}, '
                f'verification_status={(self.verification_status if hasattr(self, "verification_status") else None)!r}, '
                f'verification={(self.verification if hasattr(self, "verification") else None)!r}, '
                f'network_transaction_reference={(self.network_transaction_reference if hasattr(self, "network_transaction_reference") else None)!r}, '
                f'authentication_result={(self.authentication_result if hasattr(self, "authentication_result") else None)!r}, '
                f'bin_details={(self.bin_details if hasattr(self, "bin_details") else None)!r}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!r}, '
                f'network_token={(self.network_token if hasattr(self, "network_token") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'last_digits={(self.last_digits if hasattr(self, "last_digits") else None)!s}, '
                f'brand={(self.brand if hasattr(self, "brand") else None)!s}, '
                f'expiry={(self.expiry if hasattr(self, "expiry") else None)!s}, '
                f'billing_address={(self.billing_address if hasattr(self, "billing_address") else None)!s}, '
                f'verification_status={(self.verification_status if hasattr(self, "verification_status") else None)!s}, '
                f'verification={(self.verification if hasattr(self, "verification") else None)!s}, '
                f'network_transaction_reference={(self.network_transaction_reference if hasattr(self, "network_transaction_reference") else None)!s}, '
                f'authentication_result={(self.authentication_result if hasattr(self, "authentication_result") else None)!s}, '
                f'bin_details={(self.bin_details if hasattr(self, "bin_details") else None)!s}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!s}, '
                f'network_token={(self.network_token if hasattr(self, "network_token") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.address import Address


class VaultSEPADebitResponse(object):

    """Implementation of the 'Vault SEPA Debit Response' model.

    An API resource used in the response of securely storing a SEPA Debit.

    Attributes:
        iban_last_chars (str): The last characters of the IBAN used to pay.
        account_holder_name (Any): The model property of type Any.
        billing_address (Address): The portable international postal address.
            Maps to
            [AddressValidationMetadata](https://github.com/googlei18n/libaddres
            sinput/wiki/AddressValidationMetadata) and HTML 5.1 [Autofilling
            form controls: the autocomplete
            attribute](https://www.w3.org/TR/html51/sec-forms.html#autofilling-
            form-controls-the-autocomplete-attribute).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "iban_last_chars": 'iban_last_chars',
        "account_holder_name": 'account_holder_name',
        "billing_address": 'billing_address'
    }

    _optionals = [
        'iban_last_chars',
        'account_holder_name',
        'billing_address',
    ]

    def __init__(self,
                 iban_last_chars=APIHelper.SKIP,
                 account_holder_name=APIHelper.SKIP,
                 billing_address=APIHelper.SKIP):
        """Constructor for the VaultSEPADebitResponse class"""

        # Initialize members of the class
        if iban_last_chars is not APIHelper.SKIP:
            self.iban_last_chars = iban_last_chars 
        if account_holder_name is not APIHelper.SKIP:
            self.account_holder_name = account_holder_name 
        if billing_address is not APIHelper.SKIP:
            self.billing_address = billing_address 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        iban_last_chars = dictionary.get("iban_last_chars") if dictionary.get("iban_last_chars") else APIHelper.SKIP
        account_holder_name = dictionary.get("account_holder_name") if dictionary.get("account_holder_name") else APIHelper.SKIP
        billing_address = Address.from_dictionary(dictionary.get('billing_address')) if 'billing_address' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(iban_last_chars,
                   account_holder_name,
                   billing_address)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'iban_last_chars={(self.iban_last_chars if hasattr(self, "iban_last_chars") else None)!r}, '
                f'account_holder_name={(self.account_holder_name if hasattr(self, "account_holder_name") else None)!r}, '
                f'billing_address={(self.billing_address if hasattr(self, "billing_address") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'iban_last_chars={(self.iban_last_chars if hasattr(self, "iban_last_chars") else None)!s}, '
                f'account_holder_name={(self.account_holder_name if hasattr(self, "account_holder_name") else None)!s}, '
                f'billing_address={(self.billing_address if hasattr(self, "billing_address") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.address import Address
from paypalrestapis.models.authentication_response import AuthenticationResponse


class GooglePayCardResponse(object):

    """Implementation of the 'Google Pay Card Response' model.

    The payment card to use to fund a Google Pay payment response. Can be a
    credit or debit card.

    Attributes:
        name (str): The card holder's name as it appears on the card.
        last_digits (str): The last digits of the payment card.
        mtype (CardType): Type of card. i.e Credit, Debit and so on.
        brand (CardBrand): The card network or brand. Applies to credit,
            debit, gift, and payment cards.
        billing_address (Address): The portable international postal address.
            Maps to
            [AddressValidationMetadata](https://github.com/googlei18n/libaddres
            sinput/wiki/AddressValidationMetadata) and HTML 5.1 [Autofilling
            form controls: the autocomplete
            attribute](https://www.w3.org/TR/html51/sec-forms.html#autofilling-
            form-controls-the-autocomplete-attribute).
        authentication_result (AuthenticationResponse): Results of
            Authentication such as 3D Secure.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "last_digits": 'last_digits',
        "mtype": 'type',
        "brand": 'brand',
        "billing_address": 'billing_address',
        "authentication_result": 'authentication_result'
    }

    _optionals = [
        'name',
        'last_digits',
        'mtype',
        'brand',
        'billing_address',
        'authentication_result',
    ]

    def __init__(self,
                 name=APIHelper.SKIP,
                 last_digits=APIHelper.SKIP,
                 mtype=APIHelper.SKIP,
                 brand=APIHelper.SKIP,
                 billing_address=APIHelper.SKIP,
                 authentication_result=APIHelper.SKIP):
        """Constructor for the GooglePayCardResponse class"""

        # Initialize members of the class
        if name is not APIHelper.SKIP:
            self.name = name 
        if last_digits is not APIHelper.SKIP:
            self.last_digits = last_digits 
        if mtype is not APIHelper.SKIP:
            self.mtype = mtype 
        if brand is not APIHelper.SKIP:
            self.brand = brand 
        if billing_address is not APIHelper.SKIP:
            self.billing_address = billing_address 
        if authentication_result is not APIHelper.SKIP:
            self.authentication_result = authentication_result 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get("name") if dictionary.get("name") else APIHelper.SKIP
        last_digits = dictionary.get("last_digits") if dictionary.get("last_digits") else APIHelper.SKIP
        mtype = dictionary.get("type") if dictionary.get("type") else APIHelper.SKIP
        brand = dictionary.get("brand") if dictionary.get("brand") else APIHelper.SKIP
        billing_address = Address.from_dictionary(dictionary.get('billing_address')) if 'billing_address' in dictionary.keys() else APIHelper.SKIP
        authentication_result = AuthenticationResponse.from_dictionary(dictionary.get('authentication_result')) if 'authentication_result' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(name,
                   last_digits,
                   mtype,
                   brand,
                   billing_address,
                   authentication_result)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!r}, '
                f'last_digits={(self.last_digits if hasattr(self, "last_digits") else None)!r}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!r}, '
                f'brand={(self.brand if hasattr(self, "brand") else None)!r}, '
                f'billing_address={(self.billing_address if hasattr(self, "billing_address") else None)!r}, '
                f'authentication_result={(self.authentication_result if hasattr(self, "authentication_result") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'name={(self.name if hasattr(self, "name") else None)!s}, '
                f'last_digits={(self.last_digits if hasattr(self, "last_digits") else None)!s}, '
                f'mtype={(self.mtype if hasattr(self, "mtype") else None)!s}, '
                f'brand={(self.brand if hasattr(self, "brand") else None)!s}, '
                f'billing_address={(self.billing_address if hasattr(self, "billing_address") else None)!s}, '
                f'authentication_result={(self.authentication_result if hasattr(self, "authentication_result") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class AuthorizationStatus(object):

    """Implementation of the 'Authorization Status' enum.

    The status for the authorized payment.

    Attributes:
        CREATED: The enum member of type str.
        CAPTURED: The enum member of type str.
        DENIED: The enum member of type str.
        PARTIALLY_CAPTURED: The enum member of type str.
        VOIDED: The enum member of type str.
        PENDING: The enum member of type str.

    """
    CREATED = 'CREATED'

    CAPTURED = 'CAPTURED'

    DENIED = 'DENIED'

    PARTIALLY_CAPTURED = 'PARTIALLY_CAPTURED'

    VOIDED = 'VOIDED'

    PENDING = 'PENDING'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PhoneType(object):

    """Implementation of the 'Phone Type' enum.

    The phone type.

    Attributes:
        FAX: The enum member of type str.
        HOME: The enum member of type str.
        MOBILE: The enum member of type str.
        OTHER: The enum member of type str.
        PAGER: The enum member of type str.

    """
    FAX = 'FAX'

    HOME = 'HOME'

    MOBILE = 'MOBILE'

    OTHER = 'OTHER'

    PAGER = 'PAGER'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class CardBrand(object):

    """Implementation of the 'Card Brand' enum.

    The card network or brand. Applies to credit, debit, gift, and payment
    cards.

    Attributes:
        VISA: The enum member of type str.
        MASTERCARD: The enum member of type str.
        DISCOVER: The enum member of type str.
        AMEX: The enum member of type str.
        SOLO: The enum member of type str.
        JCB: The enum member of type str.
        STAR: The enum member of type str.
        DELTA: The enum member of type str.
        SWITCH: The enum member of type str.
        MAESTRO: The enum member of type str.
        CB_NATIONALE: The enum member of type str.
        CONFIGOGA: The enum member of type str.
        CONFIDIS: The enum member of type str.
        ELECTRON: The enum member of type str.
        CETELEM: The enum member of type str.
        CHINA_UNION_PAY: The enum member of type str.
        DINERS: The enum member of type str.
        ELO: The enum member of type str.
        HIPER: The enum member of type str.
        HIPERCARD: The enum member of type str.
        RUPAY: The enum member of type str.
        GE: The enum member of type str.
        SYNCHRONY: The enum member of type str.
        UNKNOWN: The enum member of type str.

    """
    VISA = 'VISA'

    MASTERCARD = 'MASTERCARD'

    DISCOVER = 'DISCOVER'

    AMEX = 'AMEX'

    SOLO = 'SOLO'

    JCB = 'JCB'

    STAR = 'STAR'

    DELTA = 'DELTA'

    SWITCH = 'SWITCH'

    MAESTRO = 'MAESTRO'

    CB_NATIONALE = 'CB_NATIONALE'

    CONFIGOGA = 'CONFIGOGA'

    CONFIDIS = 'CONFIDIS'

    ELECTRON = 'ELECTRON'

    CETELEM = 'CETELEM'

    CHINA_UNION_PAY = 'CHINA_UNION_PAY'

    DINERS = 'DINERS'

    ELO = 'ELO'

    HIPER = 'HIPER'

    HIPERCARD = 'HIPERCARD'

    RUPAY = 'RUPAY'

    GE = 'GE'

    SYNCHRONY = 'SYNCHRONY'

    UNKNOWN = 'UNKNOWN'




# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper
from paypalrestapis.models.money import Money


class Level2CardProcessingData(object):

    """Implementation of the 'Level 2 Card Processing Data' model.

    The level 2 card processing data collections. If your merchant account has
    been configured for Level 2 processing this field will be passed to the
    processor on your behalf. Please contact your PayPal Technical Account
    Manager to define level 2 data for your business.

    Attributes:
        invoice_id (str): Use this field to pass a purchase identification
            value of up to 12 ASCII characters for AIB and 17 ASCII characters
            for all other processors.
        tax_total (Money): The currency and amount for a financial
            transaction, such as a balance or payment due.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "invoice_id": 'invoice_id',
        "tax_total": 'tax_total'
    }

    _optionals = [
        'invoice_id',
        'tax_total',
    ]

    def __init__(self,
                 invoice_id=APIHelper.SKIP,
                 tax_total=APIHelper.SKIP):
        """Constructor for the Level2CardProcessingData class"""

        # Initialize members of the class
        if invoice_id is not APIHelper.SKIP:
            self.invoice_id = invoice_id 
        if tax_total is not APIHelper.SKIP:
            self.tax_total = tax_total 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        invoice_id = dictionary.get("invoice_id") if dictionary.get("invoice_id") else APIHelper.SKIP
        tax_total = Money.from_dictionary(dictionary.get('tax_total')) if 'tax_total' in dictionary.keys() else APIHelper.SKIP
        # Return an object of this model
        return cls(invoice_id,
                   tax_total)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'invoice_id={(self.invoice_id if hasattr(self, "invoice_id") else None)!r}, '
                f'tax_total={(self.tax_total if hasattr(self, "tax_total") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'invoice_id={(self.invoice_id if hasattr(self, "invoice_id") else None)!s}, '
                f'tax_total={(self.tax_total if hasattr(self, "tax_total") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from paypalrestapis.api_helper import APIHelper
from paypalrestapis.configuration import Server
from paypalrestapis.controllers.base_controller import BaseController
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter
from paypalrestapis.http.http_method_enum import HttpMethodEnum
from apimatic_core.authentication.multiple.single_auth import Single
from paypalrestapis.models.order import Order
from paypalrestapis.models.order_authorize_response import OrderAuthorizeResponse
from paypalrestapis.exceptions.error_exception import ErrorException


class OrdersController(BaseController):

    """A Controller to access Endpoints in the paypalrestapis API."""
    def __init__(self, config):
        super(OrdersController, self).__init__(config)

    def orders_create(self,
                      options=dict()):
        """Does a POST request to /v2/checkout/orders.

        Creates an order. Merchants and partners can add Level 2 and 3 data to
        payments to reduce risk and payment processing costs. For more
        information about processing payments, see <a
        href="https://developer.paypal.com/docs/checkout/advanced/processing/">
        checkout</a> or <a
        href="https://developer.paypal.com/docs/multiparty/checkout/advanced/pr
        ocessing/">multiparty checkout</a>.<blockquote><strong>Note:</strong>
        For error handling and troubleshooting, see <a
        href="/api/rest/reference/orders/v2/errors/#create-order">Orders v2
        errors</a>.</blockquote>

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    body -- OrderRequest -- The request body parameter.
                    pay_pal_request_id -- str -- The server stores keys for 6
                        hours. The API callers can request the times to up to
                        72 hours by speaking to their Account Manager.
                    pay_pal_partner_attribution_id -- str -- The request
                        header parameter.
                    pay_pal_client_metadata_id -- str -- The request header
                        parameter.
                    prefer -- str -- The preferred server response upon
                        successful completion of the request. Value
                        is:<ul><li><code>return=minimal</code>. The server
                        returns a minimal response to optimize communication
                        between the API caller and the server. A minimal
                        response includes the <code>id</code>,
                        <code>status</code> and HATEOAS
                        links.</li><li><code>return=representation</code>. The
                        server returns a complete resource representation,
                        including the current state of the resource.</li></ul>

        Returns:
            Order: Response from the API. A successful response to an
                idempotent request returns the HTTP `200 OK` status code with
                a JSON response body that shows order details.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v2/checkout/orders')
            .http_method(HttpMethodEnum.POST)
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(options.get('body', None)))
            .header_param(Parameter()
                          .key('PayPal-Request-Id')
                          .value(options.get('pay_pal_request_id', None)))
            .header_param(Parameter()
                          .key('PayPal-Partner-Attribution-Id')
                          .value(options.get('pay_pal_partner_attribution_id', None)))
            .header_param(Parameter()
                          .key('PayPal-Client-Metadata-Id')
                          .value(options.get('pay_pal_client_metadata_id', None)))
            .header_param(Parameter()
                          .key('Prefer')
                          .value(options.get('prefer', None)))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('Oauth2'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Order.from_dictionary)
            .local_error('400', 'Request is not well-formed, syntactically incorrect, or violates schema.', ErrorException)
            .local_error('401', 'Authentication failed due to missing authorization header, or invalid authentication credentials.', ErrorException)
            .local_error('422', 'The requested action could not be performed, semantically incorrect, or failed business validation.', ErrorException)
            .local_error('default', 'The error response.', ErrorException)
        ).execute()

    def orders_get(self,
                   options=dict()):
        """Does a GET request to /v2/checkout/orders/{id}.

        Shows details for an order, by ID.<blockquote><strong>Note:</strong>
        For error handling and troubleshooting, see <a
        href="/api/rest/reference/orders/v2/errors/#get-order">Orders v2
        errors</a>.</blockquote>

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    id -- str -- The ID of the order for which to show details.
                    fields -- str -- A comma-separated list of fields that
                        should be returned for the order. Valid filter field
                        is `payment_source`.

        Returns:
            Order: Response from the API. A successful request returns the
                HTTP `200 OK` status code and a JSON response body that shows
                order details.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v2/checkout/orders/{id}')
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                            .key('id')
                            .value(options.get('id', None))
                            .should_encode(True))
            .query_param(Parameter()
                         .key('fields')
                         .value(options.get('fields', None)))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .auth(Single('Oauth2'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Order.from_dictionary)
            .local_error('401', 'Authentication failed due to missing authorization header, or invalid authentication credentials.', ErrorException)
            .local_error('404', 'The specified resource does not exist.', ErrorException)
            .local_error('default', 'The error response.', ErrorException)
        ).execute()

    def orders_patch(self,
                     options=dict()):
        """Does a PATCH request to /v2/checkout/orders/{id}.

        Updates an order with a `CREATED` or `APPROVED` status. You cannot
        update an order with the `COMPLETED` status.<br/><br/>To make an
        update, you must provide a `reference_id`. If you omit this value with
        an order that contains only one purchase unit, PayPal sets the value
        to `default` which enables you to use the path:
        <code>\"/purchase_units/@reference_id=='default'/{attribute-or-object}\
        "</code>. Merchants and partners can add Level 2 and 3 data to
        payments to reduce risk and payment processing costs. For more
        information about processing payments, see <a
        href="https://developer.paypal.com/docs/checkout/advanced/processing/">
        checkout</a> or <a
        href="https://developer.paypal.com/docs/multiparty/checkout/advanced/pr
        ocessing/">multiparty checkout</a>.<blockquote><strong>Note:</strong>
        For error handling and troubleshooting, see <a
        href=\"/api/rest/reference/orders/v2/errors/#patch-order\">Orders v2
        errors</a>.</blockquote>Patchable attributes or
        objects:<br/><br/><table><thead><th>Attribute</th><th>Op</th><th>Notes<
        /th></thead><tbody><tr><td><code>intent</code></td><td>replace</td><td>
        </td></tr><tr><td><code>payer</code></td><td>replace,
        add</td><td>Using replace op for <code>payer</code> will replace the
        whole <code>payer</code> object with the value sent in
        request.</td></tr><tr><td><code>purchase_units</code></td><td>replace,
        add</td><td></td></tr><tr><td><code>purchase_units[].custom_id</code></
        td><td>replace, add,
        remove</td><td></td></tr><tr><td><code>purchase_units[].description</co
        de></td><td>replace, add,
        remove</td><td></td></tr><tr><td><code>purchase_units[].payee.email</co
        de></td><td>replace</td><td></td></tr><tr><td><code>purchase_units[].sh
        ipping.name</code></td><td>replace,
        add</td><td></td></tr><tr><td><code>purchase_units[].shipping.email_add
        ress</code></td><td>replace,
        add</td><td></td></tr><tr><td><code>purchase_units[].shipping.phone_num
        ber</code></td><td>replace,
        add</td><td></td></tr><tr><td><code>purchase_units[].shipping.options</
        code></td><td>replace,
        add</td><td></td></tr><tr><td><code>purchase_units[].shipping.address</
        code></td><td>replace,
        add</td><td></td></tr><tr><td><code>purchase_units[].shipping.type</cod
        e></td><td>replace,
        add</td><td></td></tr><tr><td><code>purchase_units[].soft_descriptor</c
        ode></td><td>replace,
        remove</td><td></td></tr><tr><td><code>purchase_units[].amount</code></
        td><td>replace</td><td></td></tr><tr><td><code>purchase_units[].items</
        code></td><td>replace, add,
        remove</td><td></td></tr><tr><td><code>purchase_units[].invoice_id</cod
        e></td><td>replace, add,
        remove</td><td></td></tr><tr><td><code>purchase_units[].payment_instruc
        tion</code></td><td>replace</td><td></td></tr><tr><td><code>purchase_un
        its[].payment_instruction.disbursement_mode</code></td><td>replace</td>
        <td>By default, <code>disbursement_mode</code> is
        <code>INSTANT</code>.</td></tr><tr><td><code>purchase_units[].payment_i
        nstruction.payee_receivable_fx_rate_id</code></td><td>replace, add,
        remove</td><td></td></tr><tr><td><code>purchase_units[].payment_instruc
        tion.platform_fees</code></td><td>replace, add,
        remove</td><td></td></tr><tr><td><code>purchase_units[].supplementary_d
        ata.airline</code></td><td>replace, add,
        remove</td><td></td></tr><tr><td><code>purchase_units[].supplementary_d
        ata.card</code></td><td>replace, add,
        remove</td><td></td></tr><tr><td><code>application_context.client_confi
        guration</code></td><td>replace, add</td><td></td></tr></tbody></table>

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    id -- str -- The ID of the order to update.
                    body -- List[Patch] -- The request body parameter.

        Returns:
            void: Response from the API. A successful request returns the HTTP
                `204 No Content` status code with an empty object in the JSON
                response body.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v2/checkout/orders/{id}')
            .http_method(HttpMethodEnum.PATCH)
            .template_param(Parameter()
                            .key('id')
                            .value(options.get('id', None))
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(options.get('body', None)))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('Oauth2'))
        ).execute()

    def orders_confirm(self,
                       options=dict()):
        """Does a POST request to /v2/checkout/orders/{id}/confirm-payment-source.

        Payer confirms their intent to pay for the the Order with the given
        payment source.

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    id -- str -- The ID of the order for which the payer
                        confirms their intent to pay.
                    pay_pal_client_metadata_id -- str -- The request header
                        parameter.
                    prefer -- str -- The preferred server response upon
                        successful completion of the request. Value
                        is:<ul><li><code>return=minimal</code>. The server
                        returns a minimal response to optimize communication
                        between the API caller and the server. A minimal
                        response includes the <code>id</code>,
                        <code>status</code> and HATEOAS
                        links.</li><li><code>return=representation</code>. The
                        server returns a complete resource representation,
                        including the current state of the resource.</li></ul>
                    body -- ConfirmOrderRequest -- The request body parameter.

        Returns:
            Order: Response from the API. A successful request indicates that
                the payment source was added to the Order. A successful
                request returns the HTTP `200 OK` status code with a JSON
                response body that shows order details.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v2/checkout/orders/{id}/confirm-payment-source')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('id')
                            .value(options.get('id', None))
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .header_param(Parameter()
                          .key('PayPal-Client-Metadata-Id')
                          .value(options.get('pay_pal_client_metadata_id', None)))
            .header_param(Parameter()
                          .key('Prefer')
                          .value(options.get('prefer', None)))
            .body_param(Parameter()
                        .value(options.get('body', None)))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('Oauth2'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Order.from_dictionary)
            .local_error('400', 'Request is not well-formed, syntactically incorrect, or violates schema.', ErrorException)
            .local_error('403', 'Authorization failed due to insufficient permissions.', ErrorException)
            .local_error('422', 'The requested action could not be performed, semantically incorrect, or failed business validation.', ErrorException)
            .local_error('500', 'An internal server error has occurred.', ErrorException)
            .local_error('default', 'The error response.', ErrorException)
        ).execute()

    def orders_authorize(self,
                         options=dict()):
        """Does a POST request to /v2/checkout/orders/{id}/authorize.

        Authorizes payment for an order. To successfully authorize payment for
        an order, the buyer must first approve the order or a valid
        payment_source must be provided in the request. A buyer can approve
        the order upon being redirected to the rel:approve URL that was
        returned in the HATEOAS links in the create order
        response.<blockquote><strong>Note:</strong> For error handling and
        troubleshooting, see <a
        href="/api/rest/reference/orders/v2/errors/#authorize-order">Orders v2
        errors</a>.</blockquote>

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    id -- str -- The ID of the order for which to authorize.
                    pay_pal_request_id -- str -- The server stores keys for 6
                        hours. The API callers can request the times to up to
                        72 hours by speaking to their Account Manager.
                    prefer -- str -- The preferred server response upon
                        successful completion of the request. Value
                        is:<ul><li><code>return=minimal</code>. The server
                        returns a minimal response to optimize communication
                        between the API caller and the server. A minimal
                        response includes the <code>id</code>,
                        <code>status</code> and HATEOAS
                        links.</li><li><code>return=representation</code>. The
                        server returns a complete resource representation,
                        including the current state of the resource.</li></ul>
                    pay_pal_client_metadata_id -- str -- The request header
                        parameter.
                    pay_pal_auth_assertion -- str -- An API-caller-provided
                        JSON Web Token (JWT) assertion that identifies the
                        merchant. For details, see <a
                        href="/api/rest/requests/#paypal-auth-assertion">PayPal
                        -Auth-Assertion</a>.
                    body -- OrderAuthorizeRequest -- The request body
                        parameter.

        Returns:
            OrderAuthorizeResponse: Response from the API. A successful
                response to an idempotent request returns the HTTP `200 OK`
                status code with a JSON response body that shows authorized
                payment details.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v2/checkout/orders/{id}/authorize')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('id')
                            .value(options.get('id', None))
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .header_param(Parameter()
                          .key('PayPal-Request-Id')
                          .value(options.get('pay_pal_request_id', None)))
            .header_param(Parameter()
                          .key('Prefer')
                          .value(options.get('prefer', None)))
            .header_param(Parameter()
                          .key('PayPal-Client-Metadata-Id')
                          .value(options.get('pay_pal_client_metadata_id', None)))
            .header_param(Parameter()
                          .key('PayPal-Auth-Assertion')
                          .value(options.get('pay_pal_auth_assertion', None)))
            .body_param(Parameter()
                        .value(options.get('body', None)))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('Oauth2'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(OrderAuthorizeResponse.from_dictionary)
            .local_error('400', 'Request is not well-formed, syntactically incorrect, or violates schema.', ErrorException)
            .local_error('401', 'Authentication failed due to missing authorization header, or invalid authentication credentials.', ErrorException)
            .local_error('403', 'The authorized payment failed due to insufficient permissions.', ErrorException)
            .local_error('404', 'The specified resource does not exist.', ErrorException)
            .local_error('422', 'The requested action could not be performed, semantically incorrect, or failed business validation.', ErrorException)
            .local_error('500', 'An internal server error has occurred.', ErrorException)
            .local_error('default', 'The error response.', ErrorException)
        ).execute()

    def orders_capture(self,
                       options=dict()):
        """Does a POST request to /v2/checkout/orders/{id}/capture.

        Captures payment for an order. To successfully capture payment for an
        order, the buyer must first approve the order or a valid
        payment_source must be provided in the request. A buyer can approve
        the order upon being redirected to the rel:approve URL that was
        returned in the HATEOAS links in the create order
        response.<blockquote><strong>Note:</strong> For error handling and
        troubleshooting, see <a
        href="/api/rest/reference/orders/v2/errors/#capture-order">Orders v2
        errors</a>.</blockquote>

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    id -- str -- The ID of the order for which to capture a
                        payment.
                    pay_pal_request_id -- str -- The server stores keys for 6
                        hours. The API callers can request the times to up to
                        72 hours by speaking to their Account Manager.
                    prefer -- str -- The preferred server response upon
                        successful completion of the request. Value
                        is:<ul><li><code>return=minimal</code>. The server
                        returns a minimal response to optimize communication
                        between the API caller and the server. A minimal
                        response includes the <code>id</code>,
                        <code>status</code> and HATEOAS
                        links.</li><li><code>return=representation</code>. The
                        server returns a complete resource representation,
                        including the current state of the resource.</li></ul>
                    pay_pal_client_metadata_id -- str -- The request header
                        parameter.
                    pay_pal_auth_assertion -- str -- An API-caller-provided
                        JSON Web Token (JWT) assertion that identifies the
                        merchant. For details, see <a
                        href="/api/rest/requests/#paypal-auth-assertion">PayPal
                        -Auth-Assertion</a>.
                    body -- OrderCaptureRequest -- The request body parameter.

        Returns:
            Order: Response from the API. A successful response to an
                idempotent request returns the HTTP `200 OK` status code with
                a JSON response body that shows captured payment details.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v2/checkout/orders/{id}/capture')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('id')
                            .value(options.get('id', None))
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .header_param(Parameter()
                          .key('PayPal-Request-Id')
                          .value(options.get('pay_pal_request_id', None)))
            .header_param(Parameter()
                          .key('Prefer')
                          .value(options.get('prefer', None)))
            .header_param(Parameter()
                          .key('PayPal-Client-Metadata-Id')
                          .value(options.get('pay_pal_client_metadata_id', None)))
            .header_param(Parameter()
                          .key('PayPal-Auth-Assertion')
                          .value(options.get('pay_pal_auth_assertion', None)))
            .body_param(Parameter()
                        .value(options.get('body', None)))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('Oauth2'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Order.from_dictionary)
            .local_error('400', 'Request is not well-formed, syntactically incorrect, or violates schema.', ErrorException)
            .local_error('401', 'Authentication failed due to missing authorization header, or invalid authentication credentials.', ErrorException)
            .local_error('403', 'The authorized payment failed due to insufficient permissions.', ErrorException)
            .local_error('404', 'The specified resource does not exist.', ErrorException)
            .local_error('422', 'The requested action could not be performed, semantically incorrect, or failed business validation.', ErrorException)
            .local_error('500', 'An internal server error has occurred.', ErrorException)
            .local_error('default', 'The error response.', ErrorException)
        ).execute()

    def orders_track_create(self,
                            options=dict()):
        """Does a POST request to /v2/checkout/orders/{id}/track.

        Adds tracking information for an Order.

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    id -- str -- The ID of the order that the tracking
                        information is associated with.
                    body -- OrderTrackerRequest -- The request body parameter.
                    pay_pal_auth_assertion -- str -- An API-caller-provided
                        JSON Web Token (JWT) assertion that identifies the
                        merchant. For details, see <a
                        href="/api/rest/requests/#paypal-auth-assertion">PayPal
                        -Auth-Assertion</a>.

        Returns:
            Order: Response from the API. A successful response to an
                idempotent request returns the HTTP `200 OK` status code with
                a JSON response body that shows tracker details.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v2/checkout/orders/{id}/track')
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                            .key('id')
                            .value(options.get('id', None))
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(options.get('body', None)))
            .header_param(Parameter()
                          .key('PayPal-Auth-Assertion')
                          .value(options.get('pay_pal_auth_assertion', None)))
            .header_param(Parameter()
                          .key('accept')
                          .value('application/json'))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('Oauth2'))
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(Order.from_dictionary)
            .local_error('400', 'Request is not well-formed, syntactically incorrect, or violates schema.', ErrorException)
            .local_error('403', 'Authorization failed due to insufficient permissions.', ErrorException)
            .local_error('404', 'The specified resource does not exist.', ErrorException)
            .local_error('422', 'The requested action could not be performed, semantically incorrect, or failed business validation.', ErrorException)
            .local_error('500', 'An internal server error has occurred.', ErrorException)
            .local_error('default', 'The error response.', ErrorException)
        ).execute()

    def orders_trackers_patch(self,
                              options=dict()):
        """Does a PATCH request to /v2/checkout/orders/{id}/trackers/{tracker_id}.

        Updates or cancels the tracking information for a PayPal order, by ID.
        Updatable attributes or
        objects:<br/><br/><table><thead><th>Attribute</th><th>Op</th><th>Notes<
        /th></thead><tbody></tr><tr><td><code>items</code></td><td>replace</td>
        <td>Using replace op for <code>items</code> will replace the entire
        <code>items</code> object with the value sent in
        request.</td></tr><tr><td><code>notify_payer</code></td><td>replace,
        add</td><td></td></tr><tr><td><code>status</code></td><td>replace</td><
        td>Only patching status to CANCELLED is currently
        supported.</td></tr></tbody></table>

        Args:
            options (dict, optional): Key-value pairs for any of the
                parameters to this API Endpoint. All parameters to the
                endpoint are supplied through the dictionary with their names
                being the key and their desired values being the value. A list
                of parameters that can be used are::

                    id -- str -- The ID of the order that the tracking
                        information is associated with.
                    tracker_id -- str -- The order tracking ID.
                    body -- List[Patch] -- The request body parameter.

        Returns:
            void: Response from the API. A successful request returns the HTTP
                `204 No Content` status code with an empty object in the JSON
                response body.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path('/v2/checkout/orders/{id}/trackers/{tracker_id}')
            .http_method(HttpMethodEnum.PATCH)
            .template_param(Parameter()
                            .key('id')
                            .value(options.get('id', None))
                            .should_encode(True))
            .template_param(Parameter()
                            .key('tracker_id')
                            .value(options.get('tracker_id', None))
                            .should_encode(True))
            .header_param(Parameter()
                          .key('Content-Type')
                          .value('application/json'))
            .body_param(Parameter()
                        .value(options.get('body', None)))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single('Oauth2'))
        ).execute()



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper


class PayPalWalletExperienceContext(object):

    """Implementation of the 'PayPal Wallet Experience Context' model.

    Customizes the payer experience during the approval process for payment
    with PayPal.<blockquote><strong>Note:</strong> Partners and Marketplaces
    might configure <code>brand_name</code> and
    <code>shipping_preference</code> during partner account setup, which
    overrides the request values.</blockquote>

    Attributes:
        brand_name (str): The label that overrides the business name in the
            PayPal account on the PayPal site. The pattern is defined by an
            external party and supports Unicode.
        locale (str): The [language
            tag](https://tools.ietf.org/html/bcp47#section-2) for the language
            in which to localize the error-related strings, such as messages,
            issues, and suggested actions. The tag is made up of the [ISO
            639-2 language
            code](https://www.loc.gov/standards/iso639-2/php/code_list.php),
            the optional [ISO-15924 script
            tag](https://www.unicode.org/iso15924/codelists.html), and the
            [ISO-3166 alpha-2 country
            code](/api/rest/reference/country-codes/) or [M49 region
            code](https://unstats.un.org/unsd/methodology/m49/).
        shipping_preference (ShippingPreference): The location from which the
            shipping address is derived.
        return_url (str): Describes the URL.
        cancel_url (str): Describes the URL.
        landing_page (PayPalExperienceLandingPage): The type of landing page
            to show on the PayPal site for customer checkout.
        user_action (PayPalExperienceUserAction): Configures a
            <strong>Continue</strong> or <strong>Pay Now</strong> checkout
            flow.
        payment_method_preference (PayeePaymentMethodPreference): The
            merchant-preferred payment methods.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "brand_name": 'brand_name',
        "locale": 'locale',
        "shipping_preference": 'shipping_preference',
        "return_url": 'return_url',
        "cancel_url": 'cancel_url',
        "landing_page": 'landing_page',
        "user_action": 'user_action',
        "payment_method_preference": 'payment_method_preference'
    }

    _optionals = [
        'brand_name',
        'locale',
        'shipping_preference',
        'return_url',
        'cancel_url',
        'landing_page',
        'user_action',
        'payment_method_preference',
    ]

    def __init__(self,
                 brand_name=APIHelper.SKIP,
                 locale=APIHelper.SKIP,
                 shipping_preference='GET_FROM_FILE',
                 return_url=APIHelper.SKIP,
                 cancel_url=APIHelper.SKIP,
                 landing_page='NO_PREFERENCE',
                 user_action='CONTINUE',
                 payment_method_preference='UNRESTRICTED'):
        """Constructor for the PayPalWalletExperienceContext class"""

        # Initialize members of the class
        if brand_name is not APIHelper.SKIP:
            self.brand_name = brand_name 
        if locale is not APIHelper.SKIP:
            self.locale = locale 
        self.shipping_preference = shipping_preference 
        if return_url is not APIHelper.SKIP:
            self.return_url = return_url 
        if cancel_url is not APIHelper.SKIP:
            self.cancel_url = cancel_url 
        self.landing_page = landing_page 
        self.user_action = user_action 
        self.payment_method_preference = payment_method_preference 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        brand_name = dictionary.get("brand_name") if dictionary.get("brand_name") else APIHelper.SKIP
        locale = dictionary.get("locale") if dictionary.get("locale") else APIHelper.SKIP
        shipping_preference = dictionary.get("shipping_preference") if dictionary.get("shipping_preference") else 'GET_FROM_FILE'
        return_url = dictionary.get("return_url") if dictionary.get("return_url") else APIHelper.SKIP
        cancel_url = dictionary.get("cancel_url") if dictionary.get("cancel_url") else APIHelper.SKIP
        landing_page = dictionary.get("landing_page") if dictionary.get("landing_page") else 'NO_PREFERENCE'
        user_action = dictionary.get("user_action") if dictionary.get("user_action") else 'CONTINUE'
        payment_method_preference = dictionary.get("payment_method_preference") if dictionary.get("payment_method_preference") else 'UNRESTRICTED'
        # Return an object of this model
        return cls(brand_name,
                   locale,
                   shipping_preference,
                   return_url,
                   cancel_url,
                   landing_page,
                   user_action,
                   payment_method_preference)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'brand_name={(self.brand_name if hasattr(self, "brand_name") else None)!r}, '
                f'locale={(self.locale if hasattr(self, "locale") else None)!r}, '
                f'shipping_preference={(self.shipping_preference if hasattr(self, "shipping_preference") else None)!r}, '
                f'return_url={(self.return_url if hasattr(self, "return_url") else None)!r}, '
                f'cancel_url={(self.cancel_url if hasattr(self, "cancel_url") else None)!r}, '
                f'landing_page={(self.landing_page if hasattr(self, "landing_page") else None)!r}, '
                f'user_action={(self.user_action if hasattr(self, "user_action") else None)!r}, '
                f'payment_method_preference={(self.payment_method_preference if hasattr(self, "payment_method_preference") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'brand_name={(self.brand_name if hasattr(self, "brand_name") else None)!s}, '
                f'locale={(self.locale if hasattr(self, "locale") else None)!s}, '
                f'shipping_preference={(self.shipping_preference if hasattr(self, "shipping_preference") else None)!s}, '
                f'return_url={(self.return_url if hasattr(self, "return_url") else None)!s}, '
                f'cancel_url={(self.cancel_url if hasattr(self, "cancel_url") else None)!s}, '
                f'landing_page={(self.landing_page if hasattr(self, "landing_page") else None)!s}, '
                f'user_action={(self.user_action if hasattr(self, "user_action") else None)!s}, '
                f'payment_method_preference={(self.payment_method_preference if hasattr(self, "payment_method_preference") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from paypalrestapis.api_helper import APIHelper


class ACHDebitResponse(object):

    """Implementation of the 'ACH Debit Response' model.

    A Resource representing a response of vaulted a ACH Debit Account.

    Attributes:
        verification_status (str): The ach debit verification status.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "verification_status": 'verification_status'
    }

    _optionals = [
        'verification_status',
    ]

    def __init__(self,
                 verification_status='NOT_VERIFIED'):
        """Constructor for the ACHDebitResponse class"""

        # Initialize members of the class
        self.verification_status = verification_status 

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """

        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        verification_status = dictionary.get("verification_status") if dictionary.get("verification_status") else 'NOT_VERIFIED'
        # Return an object of this model
        return cls(verification_status)

    def __repr__(self):
        return (f'{self.__class__.__name__}('
                f'verification_status={(self.verification_status if hasattr(self, "verification_status") else None)!r})')

    def __str__(self):
        return (f'{self.__class__.__name__}('
                f'verification_status={(self.verification_status if hasattr(self, "verification_status") else None)!s})')



# -*- coding: utf-8 -*-

"""
paypalrestapis

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PayPalExperienceLandingPage(object):

    """Implementation of the 'PayPal Experience Landing Page' enum.

    The type of landing page to show on the PayPal site for customer checkout.

    Attributes:
        LOGIN: The enum member of type str.
        GUEST_CHECKOUT: The enum member of type str.
        NO_PREFERENCE: The enum member of type str.

    """
    LOGIN = 'LOGIN'

    GUEST_CHECKOUT = 'GUEST_CHECKOUT'

    NO_PREFERENCE = 'NO_PREFERENCE'

